@@ -41,7 +41,6 @@
 #include "service.h"
 #include "scripting/dataenginescript.h"
 
-#include "private/datacontainer_p.h"
 #include "private/service_p.h"
 #include "private/storage_p.h"
 #include "config-plasma.h"
@@ -50,6 +49,10 @@ namespace Plasma
 {
 
 DataEngine::DataEngine(const KPluginInfo &plugin, QObject *parent)
+    : DataEngine(plugin.toMetaData(), parent)
+{}
+
+DataEngine::DataEngine(const KPluginMetaData &plugin, QObject *parent)
     : QObject(parent),
       d(new DataEnginePrivate(this, plugin))
 {
@@ -64,7 +67,7 @@ DataEngine::DataEngine(const KPluginInfo &plugin, QObject *parent)
 
 DataEngine::DataEngine(QObject *parent, const QVariantList &args)
     : QObject(parent),
-      d(new DataEnginePrivate(this, KPluginInfo(args), args))
+      d(new DataEnginePrivate(this, KPluginInfo(args).toMetaData(), args))
 {
     if (d->script) {
         d->setupScriptSupport();
@@ -100,6 +103,11 @@ Service *DataEngine::serviceForSource(const QString &source)
 }
 
 KPluginInfo DataEngine::pluginInfo() const
+{
+    return KPluginInfo(d->dataEngineDescription);
+}
+
+KPluginMetaData DataEngine::metadata() const
 {
     return d->dataEngineDescription;
 }
@@ -129,7 +137,7 @@ void DataEngine::connectSource(const QString &source, QObject *visualization,
 void DataEngine::connectAllSources(QObject *visualization, uint pollingInterval,
                                    Plasma::Types::IntervalAlignment intervalAlignment) const
 {
-    foreach (DataContainer *s, d->sources) {
+    for (DataContainer *s : qAsConst(d->sources)) {
         d->connectSource(s, visualization, pollingInterval, intervalAlignment);
     }
 }
@@ -252,7 +260,7 @@ QAbstractItemModel *DataEngine::modelForSource(const QString &source)
     if (s) {
         return s->model();
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -388,7 +396,7 @@ void DataEngine::updateAllSources()
 
 void DataEngine::forceImmediateUpdateOfAllVisualizations()
 {
-    foreach (DataContainer *source, d->sources) {
+    for (DataContainer *source : qAsConst(d->sources)) {
         if (source->isUsed()) {
             source->forceImmediateUpdate();
         }
@@ -409,16 +417,16 @@ void DataEngine::setStorageEnabled(const QString &source, bool store)
 }
 
 // Private class implementations
-DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginInfo &info, const QVariantList &args)
+DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginMetaData &md, const QVariantList &args)
     : q(e),
-      dataEngineDescription(info),
+      dataEngineDescription(md),
       refCount(-1), // first ref
       checkSourcesTimerId(0),
       updateTimerId(0),
       minPollingInterval(-1),
       valid(false),
-      script(0),
-      package(0)
+      script(nullptr),
+      package(nullptr)
 {
     updateTimer.start();
 
@@ -428,12 +436,12 @@ DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginInfo &info, con
     }
 
     if (dataEngineDescription.isValid()) {
-        QString api = dataEngineDescription.property(QStringLiteral("X-Plasma-API")).toString();
+        QString api = dataEngineDescription.value(QStringLiteral("X-Plasma-API"));
 
         if (!api.isEmpty()) {
             const QString path =
                 QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                       QStringLiteral(PLASMA_RELATIVE_DATA_INSTALL_DIR "/dataengines/") + dataEngineDescription.pluginName(),
+                                       QStringLiteral(PLASMA_RELATIVE_DATA_INSTALL_DIR "/dataengines/") + dataEngineDescription.pluginId(),
                                        QStandardPaths::LocateDirectory);
             package = new Package(PluginLoader::self()->loadPackage(QStringLiteral("Plasma/DataEngine"), api));
             package->setPath(path);
@@ -448,7 +456,7 @@ DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginInfo &info, con
                 //        << dataEngineDescription.name() << "DataEngine.";
 #endif
                 delete package;
-                package = 0;
+                package = nullptr;
             }
         }
     }
@@ -457,9 +465,9 @@ DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginInfo &info, con
 DataEnginePrivate::~DataEnginePrivate()
 {
     delete script;
-    script = 0;
+    script = nullptr;
     delete package;
-    package = 0;
+    package = nullptr;
 }
 
 void DataEnginePrivate::internalUpdateSource(DataContainer *source)
@@ -509,7 +517,7 @@ DataContainer *DataEnginePrivate::source(const QString &sourceName, bool createW
     }
 
     if (!createWhenMissing) {
-        return 0;
+        return nullptr;
     }
 
     //qCDebug(LOG_PLASMA) << "DataEngine " << q->objectName() << ": could not find DataContainer " << sourceName << ", creating";
@@ -598,7 +606,7 @@ DataContainer *DataEnginePrivate::requestSource(const QString &sourceName, bool
                 if (newSource) {
                     *newSource = true;
                 }
-                QObject::connect(s, SIGNAL(becameUnused(QString)), q, SLOT(removeSource(QString)));
+                QObject::connect(s, &DataContainer::becameUnused, q, &DataEngine::removeSource);
                 emit q->sourceAdded(sourceName);
             }
         }
