@@ -21,6 +21,7 @@
 #define CONFIGVIEW_H
 
 #include <QQuickView>
+#include <QScopedPointer>
 
 #include <plasmaquick/plasmaquick_export.h>
 
@@ -59,7 +60,7 @@ public:
      * @param parent the QWindow in which this ConfigView is parented to
      **/
     ConfigView(Plasma::Applet *applet, QWindow *parent = nullptr);
-    virtual ~ConfigView();
+    ~ConfigView() override;
 
     virtual void init();
 
@@ -77,11 +78,11 @@ Q_SIGNALS:
     void appletGlobalShortcutChanged();
 
 protected:
-    void hideEvent(QHideEvent *ev) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *re) Q_DECL_OVERRIDE;
+    void hideEvent(QHideEvent *ev) override;
+    void resizeEvent(QResizeEvent *re) override;
 
 private:
-    ConfigViewPrivate *const d;
+    QScopedPointer<ConfigViewPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void updateMinimumWidth())
     Q_PRIVATE_SLOT(d, void updateMinimumHeight())
